@@ -1,7 +1,7 @@
-
 #include <config.h>
 #include <ctype.h>
 #include <string.h>
+#include <stdlib.h>
 
 #include <matecorba/matecorba.h>
 #include <matecorba/orb-core/orb-types.h>
@@ -459,7 +459,7 @@ CORBA_ORB_init (int *argc, char **argv,
 	 * tried to contact them when Evolution was started the next
 	 * time, causing it to hang, too.
 	 */
-	g_atexit (shutdown_orb);
+	atexit(shutdown_orb);
 #endif
 
 	retval->default_giop_version = GIOP_LATEST;
@@ -1442,6 +1442,12 @@ MateCORBA_get_giop_recv_limit (void)
 	return giop_recv_get_limit ();
 }
 
+void
+MateCORBA_set_giop_main_context (GMainContext *context)
+{
+	giop_set_main_context (context);
+}
+
 const MateCORBA_option matecorba_supported_options[] = {
 	{ "ORBid",              MATECORBA_OPTION_STRING,  NULL }, /* FIXME: unimplemented */
 	{ "ORBImplRepoIOR",     MATECORBA_OPTION_STRING,  NULL }, /* FIXME: unimplemented */
